# API

::: chromatic.rainbows.Rainbow
    handler: python
    selection:
      members:
        - __init__
        - bin
        - normalize
        - imshow
        - plot
        - animate_lightcurves
        - animate_spectra
